/*
 *  ------------------------------------------------------------------------------------
 *  * Copyright (c) SAS Institute Inc.
 *  *  Licensed under the Apache License, Version 2.0 (the "License");
 *  * you may not use this file except in compliance with the License.
 *  * You may obtain a copy of the License at
 *  *
 *  * http://www.apache.org/licenses/LICENSE-2.0
 *  *
 *  *  Unless required by applicable law or agreed to in writing, software
 *  * distributed under the License is distributed on an "AS IS" BASIS,
 *  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  * See the License for the specific language governing permissions and
 *  limitations under the License.
 * ----------------------------------------------------------------------------------------
 *
 */

'use strict';

var nodeExternals = require('webpack-node-externals');
var webpack       = require('webpack');
var path           = require('path');
var library       = 'restaf-server';
var APP_PATH = path.resolve(__dirname, 'src');

var outputFile;

outputFile = library + '.js';

let config = {
    context: APP_PATH,
    mode: 'development',

    entry: [
        'babel-polyfill',
        APP_PATH + '/index'
    ],

    target: 'node',
    externals: [nodeExternals()],
    output: {
        path: path.join(__dirname, 'lib'),
        library: library,
        filename: outputFile,
        libraryTarget: 'umd',
        umdNamedDefine: true

    },
    module: {
        rules: [
            {
                test   : /\.(js|jsx)$/,
                use    : [ { loader: "babel-loader" } ],
                include: APP_PATH,
                exclude: /node_modules/
            },
            { test: /\.css$/, use: [{ loader: "style-loader/useable" }, { loader: "css-loader" }] }
        ]

    },
    resolve: {
        extensions: ['.js']
    }

};

module.exports = config;
